@@ -27,6 +27,9 @@ pub mod symbol {
 	pub const CHECKMARK: &str = "\u{2713}"; //✓
 	pub const SPACE: &str = "\u{02FD}"; //˽
 	pub const EMPTY_SPACE: &str = " ";
+	pub const FOLDER_ICON_COLLAPSED: &str = "\u{25b8}"; //▸
+	pub const FOLDER_ICON_EXPANDED: &str = "\u{25be}"; //▾
+	pub const EMPTY_STR: &str = "";
 }
 
 pub fn title_branches() -> String {
@@ -364,6 +367,16 @@ pub mod commands {
 			CMD_GROUP_GENERAL,
 		)
 	}
+	pub fn find_file(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Find [{}]",
+				key_config.get_hint(key_config.file_find)
+			),
+			"find file in tree",
+			CMD_GROUP_GENERAL,
+		)
+	}
 	pub fn toggle_tabs_direct(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
@@ -1059,6 +1072,19 @@ pub mod commands {
 		)
 	}
 
+	pub fn branch_popup_rebase(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Rebase [{}]",
+				key_config.get_hint(key_config.rebase_branch),
+			),
+			"rebase a branch",
+			CMD_GROUP_BRANCHES,
+		)
+	}
+
 	pub fn compare_with_head(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
